#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
.. current_module:: speedup_work_lib
.. created_by:: Darren Xie
.. created_on:: 04/25/2021

Collect functionalities for speedup work
"""

__version__ = '0.1.1'
__release__ = '0.1.1'

__all__ = [
    'file_tool',
    'simple_log',
    'ssh_client',
]
